aboutsummaryrefslogtreecommitdiff
path: root/gcc/ira-int.h
diff options
context:
space:
mode:
authorVladimir Makarov <vmakarov@redhat.com>2009-03-30 18:51:25 +0000
committerVladimir Makarov <vmakarov@gcc.gnu.org>2009-03-30 18:51:25 +0000
commit5b0c0b2c05d84902395b6a21d82c2be2f6406812 (patch)
treec91f5be24ed9d4e8c7defad54927509c718991a7 /gcc/ira-int.h
parent9a48a93f5f4b08879c6156529560bdeb44e4c91a (diff)
downloadgcc-5b0c0b2c05d84902395b6a21d82c2be2f6406812.zip
gcc-5b0c0b2c05d84902395b6a21d82c2be2f6406812.tar.gz
gcc-5b0c0b2c05d84902395b6a21d82c2be2f6406812.tar.bz2
ira-int.h (ira_allocno): Rename left_conflicts_num to left_conflicts_size.
2009-03-30 Vladimir Makarov <vmakarov@redhat.com> * ira-int.h (ira_allocno): Rename left_conflicts_num to left_conflicts_size. (ALLOCNO_LEFT_CONFLICTS_NUM): Rename to ALLOCNO_LEFT_CONFLICTS_SIZE. * ira-color.c (allocno_spill_priority, push_allocno_to_stack, remove_allocno_from_bucket_and_push, allocno_spill_priority_compare, push_allocnos_to_stack, setup_allocno_available_regs_num): Use ALLOCNO_LEFT_CONFLICTS_SIZE instead of ALLOCNO_LEFT_CONFLICTS_NUM. (setup_allocno_left_conflicts_num): Ditto. Rename to setup_allocno_left_conflicts_size. (put_allocno_into_bucket): Use ALLOCNO_LEFT_CONFLICTS_SIZE instead of ALLOCNO_LEFT_CONFLICTS_NUM and setup_allocno_left_conflicts_size instead of setup_allocno_left_conflicts_num. * ira-build.c (ira_create_allocno): Use ALLOCNO_LEFT_CONFLICTS_SIZE instead of ALLOCNO_LEFT_CONFLICTS_NUM. From-SVN: r145312
Diffstat (limited to 'gcc/ira-int.h')
-rw-r--r--gcc/ira-int.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/gcc/ira-int.h b/gcc/ira-int.h
index 4cb3928..6e66cc4 100644
--- a/gcc/ira-int.h
+++ b/gcc/ira-int.h
@@ -405,10 +405,10 @@ struct ira_allocno
preferences of other allocnos not assigned yet during assigning
to given allocno. */
int *conflict_hard_reg_costs, *updated_conflict_hard_reg_costs;
- /* Number of the same cover class allocnos with TRUE in_graph_p
- value and conflicting with given allocno during each point of
- graph coloring. */
- int left_conflicts_num;
+ /* Size (in hard registers) of the same cover class allocnos with
+ TRUE in_graph_p value and conflicting with given allocno during
+ each point of graph coloring. */
+ int left_conflicts_size;
/* Number of hard registers of the allocno cover class really
available for the allocno allocation. */
int available_regs_num;
@@ -464,7 +464,7 @@ struct ira_allocno
((A)->conflict_hard_reg_costs)
#define ALLOCNO_UPDATED_CONFLICT_HARD_REG_COSTS(A) \
((A)->updated_conflict_hard_reg_costs)
-#define ALLOCNO_LEFT_CONFLICTS_NUM(A) ((A)->left_conflicts_num)
+#define ALLOCNO_LEFT_CONFLICTS_SIZE(A) ((A)->left_conflicts_size)
#define ALLOCNO_COVER_CLASS(A) ((A)->cover_class)
#define ALLOCNO_COVER_CLASS_COST(A) ((A)->cover_class_cost)
#define ALLOCNO_UPDATED_COVER_CLASS_COST(A) ((A)->updated_cover_class_cost)